# encoding: utf-8
require 'spec_helper'
require 'fedux_org_stdlib/recursive_file_finder'

RSpec.describe RecursiveFileFinder do
  context '#file' do
    it 'returns path to found file' do
      touch_file 'test.txt'
      finder = RecursiveFileFinder.new(file_name: 'test.txt', working_directory: absolute_path('.'))
      expect(finder.file).to eq Pathname.new(absolute_path('test.txt'))
    end

    it 'runs up file hierarchy' do
      touch_file 'test.txt'
      finder = RecursiveFileFinder.new(file_name: 'test.txt', working_directory: absolute_path('dir1/dir2/'))
      expect(finder.file).to eq Pathname.new(absolute_path('test.txt'))
    end

    it 'runs up file hierarchy and finds it in between' do
      touch_file 'dir1/test.txt'
      finder = RecursiveFileFinder.new(file_name: 'test.txt', working_directory: absolute_path('dir1/dir2/'))
      expect(finder.file).to eq Pathname.new(absolute_path('dir1/test.txt'))
    end

    it 'fails if file was not found' do
      finder = RecursiveFileFinder.new(file_name: 'test.txt', working_directory: absolute_path('dir1/dir2/'))
      expect { finder.file }.to raise_error Errno::ENOENT
    end

    it 'returns nil if told to to so' do
      finder = RecursiveFileFinder.new(file_name: 'test.txt', working_directory: absolute_path('dir1/dir2/'), raise_error: false)
      expect(finder.file).to be nil
    end
  end

  context '#directory' do
    it 'returns the directory where the file was found' do
      touch_file 'test.txt'
      finder = RecursiveFileFinder.new(file_name: 'test.txt', working_directory: absolute_path('dir1/dir2/'))
      expect(finder.directory).to eq Pathname.new(absolute_path('.'))
    end

    it 'fails if file was not found' do
      finder = RecursiveFileFinder.new(file_name: 'test.txt', working_directory: absolute_path('dir1/dir2/'))
      expect { finder.directory }.to raise_error Errno::ENOENT
    end

    it 'returns nil if told to to so' do
      finder = RecursiveFileFinder.new(file_name: 'test.txt', working_directory: absolute_path('dir1/dir2/'), raise_error: false)
      expect(finder.directory).to be nil
    end
  end
end
